close all;
clear all;
fclose all;
clc;

%% Process A/G/M data
%This function imports .txt formatted Acceleration, GPS, and Altitude
%data for post processing

%Created by: Aleskey Lykov, William Tarpley, Anton Volkov

display(' Reading File... ')
tic

[RawAwx, RawAwy, RawAwz, RawAsecTime, Awx, Awy, Awz, AsecTime, GpsE, GpsN, GpsX, GpsY, GpsVx, GpsVy,...
    GsecTime, Balt, Btemp, BsecTime, INSrate, BarRate, GPSrate] = readFile();

%Display INS data rate
toWrite = sprintf('INS data rate: %4.2f Hz', 1/(mean(INSrate)));
display(toWrite)
%Display Barometer data rate
toWrite = sprintf('Barometer data rate: %4.2f Hz', 1/(mean(BarRate)));
display(toWrite)
%Display INS data rate
toWrite = sprintf('GPS data rate: %4.2f Hz', 1/(mean(GPSrate)));
display(toWrite)

%% Remove leading Accel Data:  (Real World)
while AsecTime(1) < 0 % Delete up to X seconds
    Awx(1) = [];
    Awy(1) = [];
    Awz(1) = [];
    AsecTime(1) = [];
end

%% Remove leading Accel Data:  (Raw Data)
while RawAsecTime(1) < 0 % Delete up to X seconds
    RawAwx(1) = [];
    RawAwy(1) = [];
    RawAwz(1) = [];
    RawAsecTime(1) = [];
end

%% Remove leading GPS Data:
try
    while GsecTime(1) < 0 % Delete up to X seconds
        GpsN(1) = [];
        GpsE(1) = [];
        GpsX(1) = [];
        GpsY(1) = [];
        GpsVx(1) = [];
        GpsVy(1) = [];
        GsecTime(1) = [];
    end
catch me
end

%% Average Accel Data to get shift amount:
X_shift = mean(RawAwx(RawAsecTime < 1));
Y_shift = mean(RawAwy(RawAsecTime < 1));

%% Shift Accel Data:
RawAwx = (((RawAwx - X_shift)/32767)*4*9.803);
RawAwy = (((RawAwy - Y_shift)/32767)*4*9.803);

%% Fix Data Gaps
try
    [aGpsX, aGpsY, distGPSx, distGPSy] = combineGPSData(GpsX, GpsY); %current
    saveLatLongCSV(GpsE, GpsN);
catch me
end

%% Filter and plot data.
toc
display(' File Read. Filtering data... ')
tic

[Awx, Awy, Awz, AsecTime] = filterData(Awx, Awy, Awz, AsecTime);

toc

tic
display(' Data filtered. Integrating acceleration data... ')
%[Velx, Vely, Velz, Disx, Disy, Disz, aBiasX, aBiasY, distINSx, distINSy, distINSz]
[Velx, Vely, Velz, Disx, Disy, Disz, ~, ~, distINSx, distINSy, ~] = integrateData(Awx, Awy, Awz, AsecTime, aGpsX, aGpsY, GpsVx, GpsVy, GsecTime);
toc

plotData(Velx, Vely, Velz, Disx, Disy, Disz, Awx, Awy, Awz, aGpsX, aGpsY, AsecTime) % Code commented below:

toWrite = sprintf(' Distance traveled according to GPS: %4.2f m', (distGPSx + distGPSy));
disp(toWrite);
toWrite = sprintf(' Distance traveled according to INS: %4.2f m', (distINSx + distINSy));
disp(toWrite);

%% Plot Raw data in same method as real world   ***********(RAW DATA)**************
display(' File Read. Filtering data... ')
tic
[RawAwx, RawAwy, RawAwz, RawAsecTime] = filterData(RawAwx, RawAwy, RawAwz, RawAsecTime); 
toc

tic
display(' Data filtered. Integrating acceleration data... ')
%[Velx, Vely, Velz, Disx, Disy, Disz, aBiasX, aBiasY, distINSx, distINSy, distINSz]
[RawVelx, RawVely, RawVelz, Disx, Disy, Disz, ~, ~, distINSx, distINSy, ~] = integrateData(RawAwx, RawAwy, RawAwz, RawAsecTime, aGpsX, aGpsY, GpsVx, GpsVy, GsecTime);
toc

plotData(RawVelx, RawVely, RawVelz, Disx, Disy, Disz, RawAwx, RawAwy, RawAwz, aGpsX, aGpsY, RawAsecTime) 

%% Clean up 
fclose all;