function [Awx, Awy, Awz, AsecTime] = filterData(Awx, Awy, Awz, AsecTime, varargin) %, AsecTime)
%% This function Filters data according to the following:
%% The noise floor: The noise floor is determined by adding the absolute value of the 
%%   	maximum and minimum within the first X data points. X is determined by the length
%%    	of a range determined by Count to CountEnd. Any value within +/- Noisefloor is
%%    	pulled to 0.
%% By finding idle points. This is to detect when acceleration is no longer present and pull 
%%		values down by the offset. In addition this is used to remove drift which has slowly
%% 		built over time.
Count = 1;
CountEnd = 10;
Marker = 1;
MarkerEnd = 1;
slopeMean = 0;%#ok
slopeRange = 1;%#ok
NoiseFloor = abs(max(Awx(1:CountEnd))) + abs(min(Awx(1:CountEnd)));
display(NoiseFloor)
idleDetect = Awx(1:CountEnd);%zeros(1,10);
offSet = 0;%#ok


% Filter drifts over time. The upward slope to an offset
for i = CountEnd+1:length(Awx)  
    idleDetect(Count) = Awx(i);
    if Count == CountEnd
        if max(idleDetect) - min(idleDetect) < .05
            MarkerEnd = i - CountEnd;
            offSet = mean(idleDetect);
            Awx((i-CountEnd):end) = Awx((i-CountEnd):end) - offSet; 
            if (MarkerEnd - Marker) > 0
                slopeMean = mean(Awx(MarkerEnd-5:MarkerEnd));
                slopeRange = length(Awx(Marker:MarkerEnd));
                slopeArr =  (linspace(0,1,slopeRange))*slopeMean; 
                slopeArr = slopeArr.';
                Awx(Marker:MarkerEnd) = Awx(Marker:MarkerEnd) - slopeArr;
            end
            Marker = i;
        end
        Count = 1;
    else
        Count = Count + 1;
    end
end

%Remove values within the noise floor
for i = 1:length(Awx)
    if abs(Awx(i)) < NoiseFloor
        Awx(i) = 0;
    end 
end

Count = 1;
idleDetect = Awy(1:CountEnd);
offSet = 0;%#ok
Marker = 1;
slopeMean = 0;%#ok
slopeRange = 1;%#ok


%Repeat of above on the Y axis. 
for i = CountEnd+1:length(Awy)  
    idleDetect(Count) = Awy(i);
    if Count == CountEnd
        if max(idleDetect) - min(idleDetect) < .05
            MarkerEnd = i - CountEnd;
            offSet = mean(idleDetect);
            Awy((i-CountEnd):end) = Awy((i-CountEnd):end) - offSet; 
            if (MarkerEnd - Marker) > 0
                slopeMean = mean(Awy(MarkerEnd-5:MarkerEnd));
                slopeRange = length(Awy(Marker:MarkerEnd));
                slopeArr =  (linspace(0,1,slopeRange))*slopeMean; 
                slopeArr = slopeArr.';
                Awy(Marker:MarkerEnd) = Awy(Marker:MarkerEnd) - slopeArr;
            end
            Marker = i;
        end
        Count = 1;
    else
        Count = Count + 1;
    end
end

%Filter Y values within the noise floor.
for i = 1:length(Awy)
    if abs(Awy(i)) < NoiseFloor
        Awy(i) = 0;
    end 
end
%%Done
end