function [Velx, Vely, Velz, Disx, Disy, Disz, aBiasX, aBiasY, distINSx, distINSy, distINSz] = integrateData(Awx, Awy, Awz, AsecTime, aGpsX, aGpsY, GpsVx, GpsVy, GsecTime) % Code commented below:
%% This function:
% Integrates acceleration data to get velocity data
% Integrates velocity data to get displacement data

posRstFreq = 0; %Set INS path to GPS position once every X GPS readings
velRstFreq = 0; %Set INS path to GPS velocity once every X GPS readings


%% Creating bins (finding where AsecTime matches GsecTime)
try
    rstPts(length(GsecTime)-1) = 0;
    j = 1;
    for i = 2:length(GsecTime)
        while j < length(AsecTime) && GsecTime(i) > AsecTime(j)
            j = j + 1;
        end
        rstPts(i-1) = j;
    end
    rstPts(length(rstPts)) = []; % No need to reset to GPS data at very end
catch me
end    
    
    for i = 2:length(AsecTime) % Create array of differences in seconds
        aDiff(i-1) = AsecTime(i)-AsecTime(i-1);%#ok
    end

%% Velocity

Velx(length(Awx)) = 0; % Velocity Initialization
Vely(length(Awy)) = 0;
Velz(length(Awz)) = 0;

aBiasX = 0*ones(length(AsecTime),1);
aBiasY = 0*ones(length(AsecTime),1);
aBiasZ = 0*ones(length(AsecTime),1);

j = 1;
for i = 2:length(AsecTime) % Trapezoidal rule for each time sample
    aBiasX(i) = aBiasX(i-1);
    aBiasY(i) = aBiasY(i-1);
    aBiasZ(i) = aBiasZ(i-1);
    Velx(i) = Velx(i-1)+((((Awx(i)-aBiasX(i)) + (Awx(i-1)-aBiasX(i)))/2)*aDiff(i-1));
    Vely(i) = Vely(i-1)+((((Awy(i)-aBiasY(i)) + (Awy(i-1)-aBiasY(i)))/2)*aDiff(i-1));
    Velz(i) = Velz(i-1)+((((Awz(i)-aBiasZ(i)) + (Awz(i-1)-aBiasZ(i)))/2)*aDiff(i-1));
    try
        if i == rstPts(j)
            %         if j > 1
            %             aDiffx = (Velx(rstPts(j))-Velx(rstPts(j-1))) - (GpsVx(j)-GpsVx(j-1)); % X velocity difference
            %             aDiffy = (Vely(rstPts(j))-Vely(rstPts(j-1))) - (GpsVy(j)-GpsVy(j-1)); % Y velocity difference
            %             aDiffz = (Velz(rstPts(j))-Velz(rstPts(j-1))); % Z velocity difference (with reference to 0)
            %             tDiff = AsecTime(rstPts(j)) - AsecTime(rstPts(j-1)); % Time difference
            %         else
            %             aDiffx = Velx(rstPts(j)) - GpsVx(j); % X velocity difference
            %             aDiffy = Vely(rstPts(j)) - GpsVy(j); % Y velocity difference
            %             aDiffz = Velz(rstPts(j)); % Z velocity difference (with reference to 0)
            %             tDiff = AsecTime(rstPts(j)); % Time difference
            %         end
            %         aBiasX(i) = .5*aDiffx/tDiff;
            %         aBiasY(i) = .5*aDiffy/tDiff;
            %         aBiasZ(i) = .5*aDiffz/tDiff;
            
            %         aBiasX(i) = .1*aDiffx/tDiff;
            %         aBiasY(i) = .1*aDiffy/tDiff;
            %         aBiasZ(i) = .1*aDiffz/tDiff;
            %
            if mod(j, velRstFreq) == 0
                Velx(i) = GpsVx(j);
                Vely(i) = GpsVy(j);
                Velz(i) = 0;
            end
            
            if j < length(rstPts)
                j = j + 1;
            end
        end
    catch me
    end
end

%% Displacement

Disx(length(Velx)) = 0; % Displacement Initialization
Disy(length(Vely)) = 0;
Disz(length(Velz)) = 0;

j = 1;
for i = 2:length(Velx) % Trapezoidal rule for each time sample
    Disx(i) = Disx(i-1)+(((Velx(i) + Velx(i-1))/2)*aDiff(i-1));
    Disy(i) = Disy(i-1)+(((Vely(i) + Vely(i-1))/2)*aDiff(i-1));
    Disz(i) = Disz(i-1)+(((Velz(i) + Velz(i-1))/2)*aDiff(i-1));
    try
        if i == rstPts(j)
            if mod(j, posRstFreq) == 0
                Disx(i) = aGpsX(j);
                Disy(i) = aGpsY(j);
                Disz(i) = 0;
            end
            
            if j < length(rstPts)
                j = j + 1;
            end
        end
    catch me
    end
end



%% Absolute Value INS Displacement Integration:
aDisx(length(Velx)) = 0; % Displacement Initialization
aDisy(length(Vely)) = 0;
aDisz(length(Velz)) = 0;
for i = 2:length(Velx) % Trapezoidal rule for each time sample
    aDisx(i) = aDisx(i-1)+abs(((Velx(i) + Velx(i-1))/2)*aDiff(i-1));
    aDisy(i) = aDisy(i-1)+abs(((Vely(i) + Vely(i-1))/2)*aDiff(i-1));
    aDisz(i) = aDisz(i-1)+abs(((Velz(i) + Velz(i-1))/2)*aDiff(i-1));
end

distINSx = aDisx(length(Velx));
distINSy = aDisy(length(Velx));
distINSz = aDisz(length(Velx));
end