function [RawAwx, RawAwy, RawAwz, RawAsecTime,  Awx, Awy, Awz, AsecTime, GpsE, GpsN, GpsX, GpsY, GpsVx, GpsVy, GsecTime, Balt, Btemp, BsecTime, INSrate, BarRate, GPSrate] = readFile()
%% Interprets data from text file for the following parameters:
% Awx = x-axis world-referenced acceleration
% Awy = y-axis world-referenced acceleration
% Awz = z-axis world-referenced acceleration
% secTime = nanosecond-resolution time base

% Provides current path string
Path = pwd;
% Uses current path string to open GUI window for location of text file.
[FileName,PathName,~] = uigetfile('*.txt',Path, 'Real World File');

% Open file for script use
fileID = fopen([PathName '\' FileName]); %open file
if fileID==-1 % Error Checking
    display('Error opening Real World Data.');
    return
end

formatSpec = '%s';
% Provides the specified format -- Current as of 04/03/2014
Master = textscan(fileID,formatSpec,'delimiter', '\n', 'HeaderLines', 0);
Smaster = char(Master{1});
%% Close file:
fclose(fileID);

%% Use this for "PROC.txt" acceleration data - comment out PROCraw.txt code below!:
% Provides the specified format -- Current as of 04/03/2014

display('Parsing Accel Data...')
tic


Sins = Smaster;

logArrINS = zeros(length(Sins),1);
logArrGPS = zeros(length(Sins),1);
logArrBAR = zeros(length(Sins),1);

for i = 1:length(Smaster) %Separate INS,GPS,Bar
    if strcmp('INS:', Sins(i,1:4))
        logArrINS(i) = 1;
    elseif strcmp('***', Smaster(i,1:3))
        logArrGPS(i) = 1;
    elseif strcmp('** ', Smaster(i,1:3))
        logArrBAR(i) = 1;
    end
end

%Remove none INS,GPS,BAR values
Sgps = Sins(logical(logArrGPS),:);
Sbar = Sins(logical(logArrBAR),:);
Sins = Sins(logical(logArrINS),:);


% Define size of arrays
sizeV = size(Sins);
%Pre allocate space
S1 = cell(sizeV(1),1);
AsecTime = zeros(sizeV(1),1);
Awx = zeros(sizeV(1),1);
Awy = zeros(sizeV(1),1);
Awz = zeros(sizeV(1),1);
INSrate = zeros(sizeV(1),1);

formatSpec2 = '%*s @%f64 %*s %*s %f64 %*s %f64 %*s %f64';
for i = 1:sizeV(1)
    S1{i} = textscan(Sins(i,:), formatSpec2);
    % Transfer data to variables
    
    AsecTime(i) = S1{i,1}{1,1};
    Awx(i) = S1{i,1}{1,2};
    Awy(i) = S1{i,1}{1,3};
    Awz(i) = S1{i,1}{1,4};
    if i == 1
        INSrate(i) = AsecTime(i);
    else
        INSrate(i) = AsecTime(i) - AsecTime(i-1);
    end
end

toc

%% GPS coordinates and X, Y, Vx, Vy from PROC.txt:
% Provides the specified format -- Current as of 04/07/2014

display('Parsing GPS Data...')
tic

sizeV = size(Sgps);

%Pre allocate space
S2 = cell(sizeV(1),1);
GsecTime = zeros(sizeV(1),1);
GpsN = zeros(sizeV(1),1);
GpsE = zeros(sizeV(1),1);
GpsX = zeros(sizeV(1),1);
GpsY = zeros(sizeV(1),1);
GpsVx = zeros(sizeV(1),1);
GpsVy = zeros(sizeV(1),1);
GPSrate = zeros(sizeV(1),1);

formatSpec2 = '%*s @%f64 %*s %*s %f64 %*s %f64 %*s %f64 %*s %f64 %*s %f64 %*s %f64'; % GPS line format
for i = 1:sizeV(1)
    S2{i} = textscan(Sgps(i,:), formatSpec2);
    % Transfer data to variables: GsecTime, GpsE, GpsN, GpsX, GpsY, GpsVx, GpsVy
    GsecTime(i) = S2{i,1}{1,1};
    GpsN(i) = S2{i,1}{1,2};
    GpsE(i) = S2{i,1}{1,3};
    GpsX(i) = S2{i,1}{1,4};
    GpsY(i) = S2{i,1}{1,5};
    GpsVx(i) = S2{i,1}{1,6};
    GpsVy(i) = S2{i,1}{1,7};
    if i == 1
        GPSrate(i) = GsecTime(i);
    else
        GPSrate(i) = GsecTime(i) - GsecTime(i-1);
    end
end

toc
%% Bar altitude and temperature from PROC.txt:

% Provides the specified format -- Current as of 04/07/2014

display('Parsing BAR Data...')
tic

sizeV = size(Sbar);

%Pre allocate space
S3 = cell(sizeV(1),1);
BsecTime = zeros(sizeV(1),1);
Balt = zeros(sizeV(1),1);
Btemp = zeros(sizeV(1),1);
BarRate = zeros(sizeV(1),1);

formatSpec2 = '%*s %*s @%f64 %*s %*s %f64 %*s %f64'; % BAR line format
for i = 1:sizeV(1)
    S3{i} = textscan(Sbar(i,:), formatSpec2);
    % Transfer data to variables: Balt, Btemp, BsecTime
    BsecTime(i) = S3{i,1}{1,1};
    Balt(i) = S3{i,1}{1,2};
    Btemp(i) = S3{i,1}{1,3};
    if i == 1
        BarRate(i) = BsecTime(i);
    else
        BarRate(i) = BsecTime(i) - BsecTime(i-1);
    end
end

toc

%% Get Raw file location
% Provides current path string
Path = pwd;
% Uses current path string to open GUI window for location of text file.
[FileName,PathName,~] = uigetfile('*.txt',Path, 'Raw Data');

% Open file for script use
fileID = fopen([PathName '\' FileName]); %open file
if fileID==-1 % Error Checking
    display('Error opening Raw Data.');
    return
end

%% Use this for "PROCraw.txt" - run just this .m and comment out PROC.txt code above!:
formatSpec = '@%f64 %*s %*s %f64 %*s %f64 %*s %f64 %*s %f64 %*s %f64 %*s %f64';
% Provides the specified format -- Current as of 04/03/2014
C = textscan(fileID,formatSpec, 'HeaderLines', 1);

% Transfer data to variables
RawAsecTime = C{1};
RawAwx = C{2};
RawAwy = C{3};
RawAwz = C{4};
RawGx = C{5};%#ok Not used in this iteration
RawGy = C{6};%#ok Not used in this iteration
RawGz = C{7};%#ok Not used in this iteration


end